@@ -3,14 +3,16 @@
 
 __author__ = """Elias Dabbas"""
 __email__ = 'eliasdabbas@gmail.com'
-__version__ = '0.9.1'
+__version__ = '0.10.3'
 
 from advertools.ad_create import ad_create
 from advertools.ad_from_string import ad_from_string
-from advertools.emoji import emoji_search, emoji_df
+from advertools.spider import crawl
+from advertools.emoji import *
 from advertools.extract import *
 from advertools.kw_generate import *
 from advertools.regex import *
+from advertools.robotstxt import *
 from advertools.sitemaps import sitemap_to_df
 from advertools.stopwords import stopwords
 from advertools.url_builders import url_utm_ga
