@@ -1,4 +1,6 @@
 """
+.. _sitemaps:
+
 Download, Parse, and Analyze XML Sitemaps
 =========================================
 
@@ -244,14 +246,17 @@ import logging
 from xml.etree import ElementTree
 from urllib.request import urlopen, Request
 
+from advertools import __version__ as version
 import pandas as pd
 
 logging.basicConfig(level=logging.INFO)
 
+headers = {'User-Agent': 'advertools-' + version}
+
 
 def _sitemaps_from_robotstxt(robots_url):
     sitemaps = []
-    robots_page = urlopen(robots_url)
+    robots_page = urlopen(Request(robots_url, headers=headers))
     for line in robots_page.readlines():
         if line.decode().lower().startswith('sitemap:'):
             sitemaps.append(line.decode().split()[-1])
@@ -302,13 +307,16 @@ def sitemap_to_df(sitemap_url):
     """
     if sitemap_url.endswith('robots.txt'):
         return pd.concat([sitemap_to_df(sitemap)
-                          for sitemap in _sitemaps_from_robotstxt(sitemap_url)])
+                          for sitemap in _sitemaps_from_robotstxt(sitemap_url)],
+                         ignore_index=True)
     if sitemap_url.endswith('xml.gz'):
         xml_text = urlopen(Request(sitemap_url,
-                                   headers={'Accept-Encoding': 'gzip'}))
+                                   headers={'Accept-Encoding': 'gzip',
+                                            'User-Agent': 'advertools-' +
+                                                          version}))
         xml_text = GzipFile(fileobj=xml_text)
     else:
-        xml_text = urlopen(sitemap_url)
+        xml_text = urlopen(Request(sitemap_url, headers=headers))
     tree = ElementTree.parse(xml_text)
     root = tree.getroot()
 
@@ -340,3 +348,6 @@ def sitemap_to_df(sitemap_url):
         sitemap_df['priority'] = sitemap_df['priority'].astype(float)
     sitemap_df['sitemap_downloaded'] = pd.Timestamp.now(tz='UTC')
     return sitemap_df
+
+
+
